﻿using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;

namespace ElasticSearchHttpClientFactory.Controllers
{
    [ApiController]
    [Route("[controller]")]
    public class SearchController : ControllerBase
    {
        private readonly ISearchService _searchService;
        public SearchController(ISearchService searchService)
        {
            _searchService = searchService;
        }

        [HttpGet("company/{companyName}")]
        public async Task<ActionResult> GetCompany(string companyName)
        {
            var result = await _searchService.CompanyName(companyName);
            return Ok(result);
        }
        
        [HttpGet("nameAndState/")]
        public async Task<ActionResult> GetNameAndState(string name, string state)
        {
            var result = await _searchService.NameAndState(name, state);
            return Ok(result);
        }

        [HttpGet("all/")]
        public async Task<ActionResult> GetAll(int skip = 0, int take = 10, string orderBy = "dateOfBirth", string direction = "asc")
        {
            var result = await _searchService.All(skip, take, orderBy, direction);
            return Ok(result);
        }
    }
}
