using System.Net.Http;
using System.Text;
using System.Threading.Tasks;

namespace ElasticSearchHttpClientFactory
{
    public class SearchService : ISearchService
    {
        private readonly HttpClient _httpClient;
        public SearchService(HttpClient httpClient)
        {
            _httpClient = httpClient;
        }

        public async Task<string> CompanyName(string companyName)
        {
            string query = @"{{
                                ""query"": {{
                                    ""match_phrase_prefix"": {{ ""companyName"" : ""{0}"" }} 
                                }}
                            }}";
            string queryWithParams = string.Format(query, companyName);
            return await SendRequest(queryWithParams);
        }

        public async Task<string> NameAndState(string name, string state)
        {
            string query = @"{{
                                ""query"": {{
                                    ""bool"": {{
                                        ""must"": [
                                            {{""match_phrase_prefix"": {{ ""fullName"" : ""{0}"" }} }}
                                           ,{{""match"": {{ ""address.state"" : ""{1}""}}}} 
                                        ]
                                    }}
                                }}
                            }}";
            string queryWithParams = string.Format(query, name, state);
            return await SendRequest(queryWithParams);
        }

        public async Task<string> All(int skip, int take, string orderBy, string direction)
        {
            string query = @"{{
                            ""sort"":{{""{2}"": {{""order"":""{3}""}}}},
                            ""from"": {0},
                            ""size"": {1}
                            }}";

            string queryWithParams = string.Format(query, skip, take, orderBy, direction);
            return await SendRequest(queryWithParams);
        }

        private async Task<string> SendRequest(string queryWithParams)
        {
            var request = new HttpRequestMessage()
            {
                Method = HttpMethod.Get,
                Content = new StringContent(queryWithParams, Encoding.UTF8, "application/json")
            };
            var response = await _httpClient.SendAsync(request);
            var content = await response.Content.ReadAsStringAsync();
            return content;
        }
    }
}